@@ -6,7 +6,7 @@ import pytest
 
 from . import util
 
-pytestmark = pytest.mark.skipif(False, reason='examples_tests are broken.')
+pytestmark = pytest.mark.skipif(True, reason='examples_tests are broken.')
 
 
 path = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'examples')
