@@ -15,6 +15,7 @@ WBITS = 16 + zlib.MAX_WBITS
 
 
 SHOULD_SCRUB = True
+REPLACEMENTS = []
 REMOVE_OLD_CASSETTES = False
 
 
@@ -35,12 +36,16 @@ def remove_headers(request, headers_to_remove=()):
 def scrub_request_body(request):
     if not SHOULD_SCRUB:
         return request
-    if not urllib.parse.urlsplit(request.uri).path == '/login':
-        return request
-    request.body = scrub_query_string(request.body)
+    if urllib.parse.urlsplit(request.uri).path == '/login':
+        request.body = scrub_query_string(request.body)
+    request.uri = scrub_uri(request.uri)
     return request
 
 
+def scrub_uri(uri):
+    return uri.replace(settings.USERNAME, TESTING_USERNAME)
+
+
 def scrub_query_string(query_string):
     request_dict = urllib.parse.parse_qs(query_string)
     if 'password' not in request_dict:
@@ -61,6 +66,8 @@ def gzip_string(incoming):
     compress_object = zlib.compressobj(6, zlib.DEFLATED, WBITS)
     start = compress_object.compress(incoming)
     end = compress_object.flush()
+    if not isinstance(start, str):
+        return start + end
     return ''.join([start, end])
 
 
@@ -68,6 +75,9 @@ def scrub_login_response(response):
     if not SHOULD_SCRUB:
         return response
     response = response.copy()
+    if 'location' in response['headers']:
+        response['headers']['location'] = [scrub_uri(uri)
+                                           for uri in response['headers']['location']]
     try:
         decompressed = zlib.decompress(response['body']['string'], WBITS).decode('utf8')
     except:
